marktools.is_component_with_stem_tremolo_attached
=================================================

.. autofunction:: abjad.tools.marktools.is_component_with_stem_tremolo_attached.is_component_with_stem_tremolo_attached
   :noindex:
